import { DatePipe } from '@angular/common';
import { Component, Input, ResourceRef, signal } from '@angular/core';
import {
  FormControl,
  FormGroup,
  ReactiveFormsModule,
  Validators,
} from '@angular/forms';

@Component({
  selector: 'app-create-todo',
  imports: [ReactiveFormsModule],
  templateUrl: './create-todo.html',
  styleUrl: './create-todo.css',
})
export class CreateTodo {
  public form!: FormGroup;
  private datePipe = new DatePipe('en-US');
  public isEditing = signal(false);
  @Input({ required: true }) tasks!: ResourceRef<any>;
  @Input() editTodo: number = -1;

  submit() {
    if (this.form.valid) {
      if (this.form.value.id == -1) {
        this.createTask(this.form.value);
      } else {
        this.updateTask(this.form.value);
      }
      this.form.controls['id'].setValue(-1);
    }
  }

  stopEdit() {
    this.isEditing.set(false);
    this.form.controls['id'].setValue(-1);
  }

  updateTask(task: Task) {
    fetch('http://localhost:2000/api/tasks/' + task.id, {
      method: 'PUT',
      body: JSON.stringify(task),
      headers: {
        'content-type': 'application/json',
      },
    }).then(() => {
      this.tasks.reload();
    });
    this.isEditing.set(false);
  }

  createTask(task: Task) {
    fetch('http://localhost:2000/api/tasks', {
      method: 'POST',
      body: JSON.stringify(task),
      headers: {
        'content-type': 'application/json',
      },
    }).then(() => {
      this.tasks.reload();
    });
  }

  editTask(task: Task) {
    this.form.controls['id'].setValue(task.id);
    this.form.controls['title'].setValue(task.title);
    this.form.controls['dueDate'].setValue(
      this.datePipe.transform(task.dueDate, 'yyyy-MM-dd'),
    );
    this.isEditing.set(true);
  }

  ngOnInit() {
    this.form = new FormGroup({
      id: new FormControl(-1),
      title: new FormControl('', Validators.required),
      dueDate: new FormControl(
        this.datePipe.transform(new Date(), 'yyyy-MM-dd'),
      ),
      done: new FormControl(false),
    });
  }
}
